@@ -1,4 +1,4 @@
-package URI::Shortener 1.001;
+package URI::Shortener 1.002;
 
 #ABSTRACT: Shorten URIs so that you don't have to rely on external services
 
@@ -92,7 +92,7 @@ sub shorten {
     }
 
     my $qq = "INSERT INTO uris (uri,created,prefix_id) VALUES (?,?,(SELECT id FROM prefix WHERE prefix=?))";
-    $self->_dbh()->do( $qq, undef, $uri, time(), $self->{prefix} ) or die $self->dbh()->errstr;
+    $self->_dbh()->do( $qq, undef, $uri, time(), $self->{prefix} ) or die $self->_dbh()->errstr;
     goto \&shorten;
 }
 
@@ -112,7 +112,7 @@ sub lengthen {
 
 sub prune_before {
     my ( $self, $when ) = @_;
-    $self->_dbh()->do( "DELETE FROM uris WHERE created < ?", undef, $when ) or die $self->dbh()->errstr;
+    $self->_dbh()->do( "DELETE FROM uris WHERE created < ?", undef, $when ) or die $self->_dbh()->errstr;
     return 1;
 }
 
@@ -155,7 +155,7 @@ URI::Shortener - Shorten URIs so that you don't have to rely on external service
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 SYNOPSIS
 
